itkwasm.image - itkwasm python documentation
Description: Module Contents: Classes:,, ImageType,,, Image,,,,, Functions:,,_default_direction,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm.image`

## Module Contents

### Classes

`ImageType` |
`Image` |

### Functions

`_default_direction` |

### API

class itkwasm.image.ImageType
  dimension: int

    2

  componentType: Union[itkwasm.int_types.IntTypes, itkwasm.float_types.FloatTypes]

    None

  pixelType: itkwasm.pixel_types.PixelTypes

    None

  components: int

    1

itkwasm.image._default_direction() → numpy.typing.ArrayLike

class itkwasm.image.Image
  imageType: Union[itkwasm.image.ImageType, Dict]

    None

  name: str

    ‘Image’

  origin: Sequence[float]

    None

  spacing: Sequence[float]

    None

  direction: numpy.typing.ArrayLike

    None

  size: Sequence[int]

    None

  metadata: Dict

    None

  data: Optional[numpy.typing.ArrayLike]

    None

  __post_init__()